@@ -2,9 +2,11 @@
    Common file for running validator functions.
 """
 import json
+import requests
 import copy
 import hashlib
 import time
+import re
 import pymongo
 import os
 from processor.connector.special_crawler.azure_crawler import AzureCrawler
@@ -125,6 +127,23 @@ def get_all_nodes(token, sub_name, sub_id, node, user, snapshot_source):
         logger.info('Get requires valid subscription, token and path.!')
     return db_records
 
+def export_template(url, hdrs, path, retry_count=3):
+    """
+    export template
+    """
+    hdrs["Content-type"] = "application/json"
+    hdrs["cache-control"] = "no-cache"
+    request_data = {
+        "resources": [ path ],
+        "options": "SkipAllParameterization"
+    }
+    response = requests.post(url, data=json.dumps(request_data), headers=hdrs)
+    if response.status_code and isinstance(response.status_code, int) and response.status_code == 202 and retry_count:
+        export_template(url, hdrs, path, retry_count=retry_count-1)
+    if response.status_code and isinstance(response.status_code, int) and response.status_code == 200:
+        data = response.json().get("template", {})
+    return response.status_code, data
+
 def get_node(token, sub_name, sub_id, node, user, snapshot_source, all_data_records):
     """ Fetch node from azure portal using rest API."""
     collection = node['collection'] if 'collection' in node else COLLECTION
@@ -152,36 +171,53 @@ def get_node(token, sub_name, sub_id, node, user, snapshot_source, all_data_reco
         hdrs = {
             'Authorization': 'Bearer %s' % token
         }
+        
+        status = None 
+        data = None
         if node['path'].startswith('/subscriptions'):
             urlstr = 'https://management.azure.com%s?api-version=%s'
             url = urlstr % (node['path'], version)
         else:
+            parent_resource_json = {}
             urlstr = 'https://management.azure.com/subscriptions/%s%s?api-version=%s'
             url = urlstr % (sub_id, node['path'], version)
+         
+        child_resource_type_list = node.get('type', "").split("/")   
+        if len(child_resource_type_list) == 2:
+            exmatch = re.search(r'/subscriptions.*/resourceGroups/.*?/', node['path'], re.I)
+            if exmatch:
+                logger.info("exmatch.groups()[0]")
+                logger.info(exmatch.group(0))
+                export_template_url = 'https://management.azure.com%sexportTemplate?api-version=2021-04-01' % (exmatch.group(0).lower())
+                status, data = export_template(export_template_url, hdrs, node['path'])
+                
         db_record['path'] = node['path']
-        # logger.info('Get Id REST API invoked!')
-        status, data = http_get_request(url, hdrs, name='\tRESOURCE:')
-        # logger.info('Get Id status: %s', status)
+        
         if status and isinstance(status, int) and status == 200:
-            
-            parent_resource_json = {}
-            child_resource_type_list = node.get('type', "").split("/")
-            if len(child_resource_type_list) > 2:
-                child_resource_type = "/".join(child_resource_type_list[2:])
-                main_resource_type = "/".join(child_resource_type_list[:2])
-                for all_data_record in all_data_records:
-                    if all_data_record["json"]["resources"][0].get("type") == main_resource_type:
-                        if "%s/" % all_data_record["json"]["resources"][0].get("id") in node["path"]:
-                            all_data_record["json"]["resources"].append(data)
-            
-            db_record['json']['resources'].append(data)
-            db_record['region'] = data.get("location")
-            data_str = json.dumps(data)
-            db_record['checksum'] = hashlib.md5(data_str.encode('utf-8')).hexdigest()
+            if data and data.get("resources"):
+                db_record['json']['resources'] = data.get("resources")
         else:
-            put_in_currentdata('errors', data)
-            logger.info("Get Id returned invalid status: %s, response: %s", status, data)
-            logger.error("Failed to get Azure resourse with given path : %s, please verify your azure connector detail and path given in snapshot.", node['path'])
+            status, data = http_get_request(url, hdrs, name='\tRESOURCE:')
+        
+            if status and isinstance(status, int) and status == 200:    
+                # parent_resource_json = {}
+                # child_resource_type_list = node.get('type', "").split("/")
+                # if len(child_resource_type_list) > 2:
+                #     child_resource_type = "/".join(child_resource_type_list[2:])
+                #     main_resource_type = "/".join(child_resource_type_list[:2])
+                #     for all_data_record in all_data_records:
+                #         if all_data_record["json"]["resources"][0].get("type") == main_resource_type:
+                #             if "%s/" % all_data_record["json"]["resources"][0].get("id") in node["path"]:
+                #                 all_data_record["json"]["resources"].append(data)
+            
+                db_record['json']['resources'].append(data)
+                db_record['region'] = data.get("location")
+                data_str = json.dumps(data)
+                db_record['checksum'] = hashlib.md5(data_str.encode('utf-8')).hexdigest()
+            else:
+                put_in_currentdata('errors', data)
+                logger.info("Get Id returned invalid status: %s, response: %s", status, data)
+                logger.error("Failed to get Azure resourse with given path : %s, please verify your azure connector detail and path given in snapshot.", node['path'])
     else:
         db_record = {}
         logger.info('Get requires valid subscription, token and path.!')
